@@ -1,6 +1,6 @@
 /* gcompris - clockgame.c
  *
- * Time-stamp: <2005/10/10 00:28:52 bruno>
+ * Time-stamp: <2006/04/05 01:16:11 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -130,10 +130,13 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 
   if(agcomprisBoard!=NULL)
     {
+      gchar *img;
       gcomprisBoard=agcomprisBoard;
 
+      img = gcompris_image_to_skin("clockgame-bg.jpg");
       gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), 
-			      gcompris_image_to_skin("clockgame-bg.jpg"));
+			      img);
+      g_free(img);
 
       /* set initial values for this level adjusted to fit the watch background */
       cx =  gcomprisBoard->width/2;
@@ -290,8 +293,10 @@ static void display_hour(guint hour)
 			 "arrow_shape_b", (double) needle_size-20,
 			 "arrow_shape_c", (double) 8.0,
 			 NULL);
+  gnome_canvas_points_free(canvasPoints);
 
   currentTime.hour=hour;
+  display_digital_time(digital_time_item, &currentTime);
 }
 
 
@@ -322,8 +327,10 @@ static void display_minute(guint minute)
 			 "arrow_shape_b", (double) needle_size-10,
 			 "arrow_shape_c", (double) 3.0,
 			 NULL);
+  gnome_canvas_points_free(canvasPoints);
 
   currentTime.minute=minute;
+  display_digital_time(digital_time_item, &currentTime);
 }
 
 static void display_second(guint second)
@@ -353,8 +360,10 @@ static void display_second(guint second)
 			 "arrow_shape_b", (double) 0,
 			 "arrow_shape_c", (double) 0,
 			 NULL);
+  gnome_canvas_points_free(canvasPoints);
 
   currentTime.second=second;
+  display_digital_time(digital_time_item, &currentTime);
 }
 
 
@@ -450,7 +459,6 @@ clockgame_create_item(GnomeCanvasGroup *parent)
 	  }
     }
 
-
   /* Create the text area for the digital time display */
   if(gcomprisBoard->level<4)
     {
@@ -575,6 +583,8 @@ clockgame_create_item(GnomeCanvasGroup *parent)
 			   NULL);
   display_digital_time(time_to_find_item, &timeToFind);
 
+  gnome_canvas_points_free(canvasPoints);
+
 }
 
 /*
