@@ -1,6 +1,6 @@
 /* gcompris - gletters.c
  *
- * Time-stamp: <2005/11/16 23:11:26 yves>
+ * Time-stamp: <2006/03/19 23:15:02 yves>
  *
  * Copyright (C) 2000 Bruno Coudoin
  * 
@@ -124,6 +124,8 @@ static  guint32              fallSpeed = 0;
 static  double               speed = 0.0;
 static  int		     gamewon;
 
+static gboolean with_sound = FALSE;
+
 /* Description of this plugin */
 static BoardPlugin menu_bp =
   {
@@ -174,7 +176,7 @@ static void level_set_score() {
 		       gcomprisBoard->width - 220, 
 		       gcomprisBoard->height - 50, 
 		       gcomprisBoard->number_of_sublevel);
-  gcompris_bar_set(GCOMPRIS_BAR_LEVEL);
+  gcompris_bar_set(GCOMPRIS_BAR_CONFIG|GCOMPRIS_BAR_LEVEL);
 }
 
 static void pause_board (gboolean pause)
@@ -297,6 +299,13 @@ static void start_board (GcomprisBoard *agcomprisBoard)
   else
     uppercase_only = FALSE;
 
+  gchar *control_sound = g_hash_table_lookup( config, "with_sound");
+
+  if (control_sound && strcmp(g_hash_table_lookup( config, "with_sound"),"True")==0)
+    with_sound = TRUE;
+  else
+    with_sound = FALSE;
+
   g_hash_table_destroy(config);
 
   if(agcomprisBoard!=NULL)
@@ -615,7 +624,9 @@ static GnomeCanvasItem *gletters_create_item(GnomeCanvasGroup *parent)
 
   gchar *letter_unichar_name= gcompris_alphabet_sound(letter);
   str2 = gcompris_get_asset_file("gcompris alphabet", NULL, "audio/x-ogg",letter_unichar_name);
-  gcompris_play_ogg(str2, NULL);
+
+  if (with_sound)
+    gcompris_play_ogg(str2, NULL);
 
   g_free(letter_unichar_name);
   g_free(str2);
@@ -772,10 +783,55 @@ static GHFunc save_table (gpointer key,
 
 static GcomprisConfCallback conf_ok(GHashTable *table)
 {
+  if (!table){
+    if (gcomprisBoard)
+      pause_board(FALSE);
+    return;
+  }
+    
   g_hash_table_foreach(table, (GHFunc) save_table, NULL);
   
+  if (gcomprisBoard){
+    gcompris_reset_locale();
+
+    GHashTable *config;
+
+    if (profile_conf)
+      config = gcompris_get_board_conf();
+    else
+      config = table;
+    
+    gcompris_change_locale(g_hash_table_lookup( config, "locale"));
+    
+    gchar *up_init_str = g_hash_table_lookup( config, "uppercase_only");
+    
+    if (up_init_str && (strcmp(up_init_str, "True")==0))
+      uppercase_only = TRUE;
+    else
+      uppercase_only = FALSE;
+
+    gchar *control_sound = g_hash_table_lookup( config, "with_sound");
+    
+    if (control_sound && strcmp(g_hash_table_lookup( config, "with_sound"),"True")==0)
+      with_sound = TRUE;
+    else
+      with_sound = FALSE;
+    
+    if (profile_conf)
+      g_hash_table_destroy(config);
+
+    load_default_charset();    
+    
+    level_set_score();
+    gletters_next_level();
+    
+    pause_board(FALSE);
+    
+  }
+
   board_conf = NULL;
   profile_conf = NULL;
+ 
 }
 
 static void
@@ -786,9 +842,12 @@ gletter_config_start(GcomprisBoard *agcomprisBoard,
   profile_conf = aProfile;
 
   gchar *label;
+
+  if (gcomprisBoard)
+    pause_board(TRUE);
   
   label = g_strdup_printf("<b>%s</b> configuration\n for profile <b>%s</b>",
-			  agcomprisBoard->name, aProfile->name);
+			  agcomprisBoard->name, aProfile ? aProfile->name : "");
 
   gcompris_configuration_window(label, (GcomprisConfCallback )conf_ok);
 
@@ -809,7 +868,17 @@ gletter_config_start(GcomprisBoard *agcomprisBoard,
     up_init = TRUE;
 
   gcompris_separator();
+
+  gchar *control_sound = g_hash_table_lookup( config, "with_sound");
+  if (control_sound && strcmp(g_hash_table_lookup( config, "with_sound"),"True")==0)
+    with_sound = TRUE;
+  else
+    with_sound = FALSE;
+  
+  GtkCheckButton  *sound_control = gcompris_boolean_box("Enable sounds", "with_sound", with_sound);
  
+  gcompris_separator();
+
   gcompris_boolean_box(_("Uppercase only text"),
 		       "uppercase_only",
 		       up_init);
