@@ -72,8 +72,6 @@ static gint actual_figure = -2;
 /* Description of this plugin */
 
 
-#define USERHOMEDIR
-
 static BoardPlugin menu_bp =
   {
     NULL,
@@ -1852,7 +1850,6 @@ void taninitstart(void){
   char* accurstr;
 
   usergtdir = gcompris_get_current_board_dirname();
-  mkdir(usergtdir, -1);         /* mmouais bof */
 
   for (i = PXSTART; i<PXNBR+PXSTART; i++){
     tabpxnam[i] = NULL;
@@ -1873,13 +1870,13 @@ void taninitstart(void){
   tanclampgrandefig();
 
 
-  boardRootItem = gnome_canvas_item_new (gnome_canvas_root(gcomprisBoard->canvas),
-					 gnome_canvas_group_get_type(),
-					 "x", 0,
-					 "y", 0,
-                                         NULL
-                                         );
-  
+  boardRootItem = GNOME_CANVAS_GROUP(gnome_canvas_item_new (gnome_canvas_root(gcomprisBoard->canvas),
+							    gnome_canvas_group_get_type(),
+							    "x", 0.0,
+							    "y", 0.0,
+							    NULL
+							    ));
+
   create_mainwindow(boardRootItem);
 
   switch (accuracy){
