@@ -71,10 +71,6 @@ static int number_of_item_y = 0;
 static int item_width;
 static int item_height;
 
-/* Keep here the limit of the column */
-static gint limit_column_x1[MAX_NUMBER_X];
-static gint limit_column_x2[MAX_NUMBER_X];
-
 static guint colorlist [] = 
   {
     0x00FFFFFF,
@@ -93,7 +89,7 @@ static guint colorlist [] =
     0xA000A0FF,
     0xF000F0FF
   };
-#define NUMBER_OF_COLOR 14
+#define NUMBER_OF_COLOR G_N_ELEMENTS(colorlist)
 
 
 /* Description of this plugin */
@@ -116,6 +112,8 @@ static BoardPlugin menu_bp =
     NULL,
     set_level,
     NULL,
+    NULL,
+    NULL,
     NULL
   };
 
@@ -125,11 +123,7 @@ static BoardPlugin menu_bp =
  *
  */
 
-BoardPlugin
-*get_bplugin_info(void)
-{
-  return &menu_bp;
-}
+GET_BPLUGIN_INFO(hanoi)
 
 /*
  * in : boolean TRUE = PAUSE : FALSE = CONTINUE
@@ -278,6 +272,7 @@ static void hanoi_destroy_all_items()
 
 }
 
+#if 0
 static void dump_solution()
 {
   guint i, j;
@@ -299,6 +294,7 @@ static void print_piece(PieceItem *piece)
 {
   g_warning("Piece: (%d,%d=%2d/%d)\n",  piece->i,  piece->j, piece->color, piece->on_top);
 }
+#endif
 
 /* ==================================== */
 static GnomeCanvasItem *hanoi_create_item(GnomeCanvasGroup *parent)
@@ -336,7 +332,7 @@ static GnomeCanvasItem *hanoi_create_item(GnomeCanvasGroup *parent)
 
   gnome_canvas_item_new (boardRootItem,
 			 gnome_canvas_text_get_type (),
-			 "text", _("Reproduce in the empty area the same tower as the one on the right"),
+			 "text", _("Build the same tower in the empty area as the one you see on the right-hand side."),
 			 "font", gcompris_skin_font_board_medium,
 			 "x", (double) BOARDWIDTH/2 +1,
 			 "y", (double) BOARDHEIGHT - 50 +1,
@@ -347,7 +343,7 @@ static GnomeCanvasItem *hanoi_create_item(GnomeCanvasGroup *parent)
 
   gnome_canvas_item_new (boardRootItem,
 			 gnome_canvas_text_get_type (),
-			 "text", _("Reproduce in the empty area the same tower as the one on the right"),
+			 "text", _("Build the same tower in the empty area as the one you see on the right-hand side."),
 			 "font", gcompris_skin_font_board_medium,
 			 "x", (double) BOARDWIDTH/2,
 			 "y", (double) BOARDHEIGHT - 50,
@@ -676,7 +672,7 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, PieceItem *data)
     case GDK_BUTTON_RELEASE:
       if(dragging) 
 	{
-	  gint i,j;
+	  gint i;
 	  gint tmpi, tmpj;
 	  double tmpx, tmpy;
 	  PieceItem *piece_src;
