@@ -180,7 +180,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 			   50,
 			   gcomprisBoard->height - 50,
 			   gcomprisBoard->number_of_sublevel);
-      gcompris_bar_set(GCOMPRIS_BAR_LEVEL);
+      gcompris_bar_set(GCOMPRIS_BAR_CONFIG|GCOMPRIS_BAR_LEVEL);
 
       imageid_next_level();
 
@@ -709,10 +709,41 @@ static GHFunc save_table (gpointer key,
 
 static GcomprisConfCallback conf_ok(GHashTable *table)
 {
+  if (!table){
+    if (gcomprisBoard)
+      pause_board(FALSE);
+    return;
+  }
+    
   g_hash_table_foreach(table, (GHFunc) save_table, NULL);
+
+  if (gcomprisBoard) {
+    gcompris_reset_locale();
+
+    GHashTable *config;
+
+    if (profile_conf)
+      config = gcompris_get_board_conf();
+    else
+      config = table;
+
+    gcompris_change_locale(g_hash_table_lookup( config, "locale"));
+  
+    if (profile_conf)
+      g_hash_table_destroy(config);
+
+    destroy_board_list();
+
+    init_xml();
+
+    imageid_next_level();
+
+    pause_board(FALSE);
+  }
   
   board_conf = NULL;
   profile_conf = NULL;
+
 }
 
 static void
@@ -722,11 +753,18 @@ config_start(GcomprisBoard *agcomprisBoard,
   board_conf = agcomprisBoard;
   profile_conf = aProfile;
 
-  gcompris_configuration_window( g_strdup_printf("<b>%s</b> configuration\n for profile <b>%s</b>",
-						 agcomprisBoard->name, 
-						 aProfile->name), 
+  if (gcomprisBoard)
+    pause_board(TRUE);
+
+  gchar *label = g_strdup_printf("<b>%s</b> configuration\n for profile <b>%s</b>",
+				 agcomprisBoard->name, 
+				 aProfile ? aProfile->name : "");
+
+  gcompris_configuration_window( label, 
 				 (GcomprisConfCallback )conf_ok);
 
+  g_free(label);
+
   /* init the combo to previously saved value */
   GHashTable *config = gcompris_get_conf( profile_conf, board_conf);
 
