@@ -158,24 +158,24 @@ class Board_list:
       self.button_unselect_all.show()
       box3.pack_start(self.button_unselect_all, False, False, 0)
 
-      self.button_locales = gtk.Button('Locales')
+      self.button_locales = gtk.Button(_('Locales'))
       self.button_locales.connect("clicked", self.locales)
       self.button_locales.show()
       box3.pack_end(self.button_locales, False, False, 0)
 
-      self.button_locales_sound = gtk.Button('Locales sound')
+      self.button_locales_sound = gtk.Button(_('Locales sound'))
       self.button_locales_sound.connect("clicked", self.locales_sound)
       self.button_locales_sound.show()
       box3.pack_end(self.button_locales_sound, False, False, 0)
 
-      self.button_wordlist = gtk.Button('Wordlist')
+      self.button_wordlist = gtk.Button(_('Wordlist'))
       self.button_wordlist.connect("clicked", self.wordlist)
       self.button_wordlist.show()
       box3.pack_end(self.button_wordlist, False, False, 0)
       #not ready yet
       self.button_wordlist.set_sensitive(False)
 
-      self.button_login = gtk.Button('Login')
+      self.button_login = gtk.Button(_('Login'))
       self.button_login.connect("clicked", self.login_configure)
       self.button_login.show()
       box3.pack_end(self.button_login, False, False, 0)
@@ -233,7 +233,7 @@ class Board_list:
         row_dict[''] =  \
                      model.append(None,
                                   [self.pixbuf_at_height('gcompris/misc/tuxplane.png', height),
-                                   _('Main menu') + '\n' + _('/'),
+                                   _('Main menu') + '\n' + '/',
                                    not board_cell[1].board_id in self.out_dict[self.active_profile.profile_id],
                                    '%s/%s' % (board_cell[1].section,board_cell[1].name), self.pixbuf_configurable(board_cell[1])])
 
