@@ -261,7 +261,7 @@ class ExpressionLevelset(object):
 
     def getDivide(self, answer):
         n = random.randint(1, 5)
-        return Number( _(u'%d \u2215 %d') % (answer*n, n), 1 )
+        return Number( _(u'%d \u00f7 %d') % (answer*n, n), 1 )
 
 class EqualityLevelset(ExpressionLevelset):
     def __init__(self):
@@ -919,5 +919,9 @@ class Gcompris_gnumch:
             return 0
 
     def end(self):
+        for i in range(0, len(self.troggles)):
+            self.troggles[i].anim.destroy()
+        if self.muncher.anim:
+            self.muncher.anim.destroy()
         self.stopGame()
         self.rootitem.destroy()
