@@ -198,12 +198,12 @@ class Gcompris_searace:
       self.race_one_command(self.left_boat)
       self.race_one_command(self.right_boat)
     else:
-      self.statusitem.set(text=_("Race is already running"))
+      self.statusitem.set(text=_("The race is already being run"))
 
   # Called by gcompris when the user click on the level icon
   def set_level(self, level):
     if(self.left_boat.timer or self.right_boat.timer):
-      self.statusitem.set(text=_("Race is already running"))
+      self.statusitem.set(text=_("The race is already being run"))
     else:
       self.gcomprisBoard.level=level;
       self.gcomprisBoard.sublevel=1;
@@ -229,7 +229,7 @@ class Gcompris_searace:
   def repeat(self):
     # Want to rerun it
     if(self.left_boat.timer or self.right_boat.timer):
-      self.statusitem.set(text=_("Race is already running"))
+      self.statusitem.set(text=_("The race is already being run"))
     else:
       self.init_boats()
       
@@ -238,9 +238,9 @@ class Gcompris_searace:
     #print("Gcompris_searace config.")
     return
               
-  def key_press(self, keyval):
+  def key_press(self, keyval, commit_str, preedit_str):
     #print("got key %i" % keyval)
-    return gtk.FALSE
+    return False
 
   # ----------------------------------------------------------------------
   # ----------------------------------------------------------------------
@@ -438,7 +438,7 @@ class Gcompris_searace:
       width=w,
       height= h,
       anchor=gtk.ANCHOR_N,
-      size_pixels=gtk.FALSE)
+      size_pixels=False)
     self.left_boat.tv.show()
     self.left_boat.sw.show()
 
@@ -463,7 +463,7 @@ class Gcompris_searace:
       width=w,
       height= h,
       anchor=gtk.ANCHOR_N,
-      size_pixels=gtk.FALSE)
+      size_pixels=False)
     self.right_boat.tv.show()
     self.right_boat.sw.show()
 
@@ -829,7 +829,7 @@ class Gcompris_searace:
       a = boat.tb.get_iter_at_line(boat.line)
       b = boat.tb.get_iter_at_line(boat.line)
       b.forward_to_line_end()
-      cmd   = boat.tb.get_text(a, b, gtk.FALSE)
+      cmd   = boat.tb.get_text(a, b, False)
       boat.line+=1
       if(cmd and cmd[0] == "\n"):
         boat.line+=1
@@ -1009,7 +1009,7 @@ class Gcompris_searace:
           fill_color_rgba=0xFF0000FFL,
           width_units=2.0
           )
-        return gtk.TRUE
+        return True
     if event.type == gtk.gdk.MOTION_NOTIFY:
       if event.state & gtk.gdk.BUTTON1_MASK:
         # Calc the angle and distance and display them in the status bar
@@ -1027,6 +1027,6 @@ class Gcompris_searace:
       if event.button == 1:
         self.ruleritem.destroy()
         self.statusitem.set(text="")
-        return gtk.TRUE
-    return gtk.FALSE
+        return True
+    return False
 
