@@ -1,6 +1,6 @@
 /* gcompris - reading.c
  *
- * Time-stamp: <2005/09/29 22:09:55 bruno>
+ * Time-stamp: <2006/04/04 00:04:46 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -180,16 +180,20 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 
   if(agcomprisBoard!=NULL)
     {
+      gchar *img;
+
       gcomprisBoard=agcomprisBoard;
 
+      img = gcompris_image_to_skin("reading-bg.jpg");
       gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas),
-			      gcompris_image_to_skin("reading-bg.jpg"));
+			      img);
+      g_free(img);
       wait_for_ready = TRUE;
       gamewon = FALSE;
 
       gcomprisBoard->level = 1;
       gcomprisBoard->maxlevel = 9;
-      gcompris_bar_set(GCOMPRIS_BAR_LEVEL);
+      gcompris_bar_set(GCOMPRIS_BAR_CONFIG|GCOMPRIS_BAR_LEVEL);
 
       font_size = PANGO_PIXELS(pango_font_description_get_size (pango_font_description_from_string (gcompris_skin_font_board_medium)));
       interline = (int) (1.5*font_size);
@@ -829,10 +833,37 @@ static GHFunc save_table (gpointer key,
 
 static GcomprisConfCallback conf_ok(GHashTable *table)
 {
+  if (!table){
+    if (gcomprisBoard)
+      pause_board(FALSE);
+    return;
+  }
+
   g_hash_table_foreach(table, (GHFunc) save_table, NULL);
+
+  if (gcomprisBoard){
+    gcompris_reset_locale();
+
+    GHashTable *config;
+    
+    if (profile_conf)
+      config = gcompris_get_board_conf();
+    else
+      config = table;
+    
+    gcompris_change_locale(g_hash_table_lookup( config, "locale"));
+  
+    if (profile_conf)
+      g_hash_table_destroy(config);
+
+    reading_next_level();
+  
+    pause_board(FALSE);
+  }
   
   board_conf = NULL;
   profile_conf = NULL;
+
 }
 
 static void
@@ -842,11 +873,18 @@ reading_config_start(GcomprisBoard *agcomprisBoard,
   board_conf = agcomprisBoard;
   profile_conf = aProfile;
 
-  gcompris_configuration_window( g_strdup_printf("<b>%s</b> configuration\n for profile <b>%s</b>",
-						 agcomprisBoard->name, 
-						 aProfile->name), 
+  if (gcomprisBoard)
+    pause_board(TRUE);
+
+  gchar *label = g_strdup_printf("<b>%s</b> configuration\n for profile <b>%s</b>",
+				 agcomprisBoard->name, 
+				 aProfile? aProfile->name: "");
+
+  gcompris_configuration_window( label, 
 				 (GcomprisConfCallback )conf_ok);
 
+  g_free(label);
+
   /* init the combo to previously saved value */
   GHashTable *config = gcompris_get_conf( profile_conf, board_conf);
 
