@@ -1,6 +1,6 @@
 /* gcompris - shapegame.c
  *
- * Time-stamp: <2005/11/12 18:56:26 bruno>
+ * Time-stamp: <2006/04/04 00:05:12 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -259,7 +259,11 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 
       g_free(filename);
       
-      gcompris_bar_set(GCOMPRIS_BAR_LEVEL|GCOMPRIS_BAR_OK);
+      if (strcmp(gcomprisBoard->name, "imagename")==0){
+	gcompris_bar_set(GCOMPRIS_BAR_CONFIG|GCOMPRIS_BAR_LEVEL|GCOMPRIS_BAR_OK);
+      } else
+	gcompris_bar_set(GCOMPRIS_BAR_LEVEL|GCOMPRIS_BAR_OK);
+      
 
       gcomprisBoard->sublevel = 0;
 
@@ -282,9 +286,13 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 
       if(default_background)
 	{
+	  gchar *img;
+
 	  // Default case, load the default background
+	  img = gcompris_image_to_skin("gcompris-shapebg.jpg");
 	  gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), 
-				  gcompris_image_to_skin("gcompris-shapebg.jpg"));
+				  img);
+	  g_free(img);
 	}
 
       shapegame_next_level();
@@ -2092,10 +2100,37 @@ static GHFunc save_table (gpointer key,
 
 static GcomprisConfCallback conf_ok(GHashTable *table)
 {
+  if (!table){
+    if (gcomprisBoard)
+      pause_board(FALSE);
+    return;
+  }
+
   g_hash_table_foreach(table, (GHFunc) save_table, NULL);
+
+  if ((gcomprisBoard) && (strcmp(gcomprisBoard->name, "imagename")==0)){
+    GHashTable *config;
+    
+    if (profile_conf)
+      config = gcompris_get_board_conf();
+    else
+      config = table;
+    
+    gcompris_reset_locale();
+    
+    gcompris_change_locale(g_hash_table_lookup( config, "locale"));
+      
+    if (profile_conf)
+      g_hash_table_destroy(config);
+    
+    shapegame_next_level();
+    
+    pause_board(FALSE);
+  }
   
   board_conf = NULL;
   profile_conf = NULL;
+
 }
 
 static void
@@ -2105,11 +2140,18 @@ config_start(GcomprisBoard *agcomprisBoard,
   board_conf = agcomprisBoard;
   profile_conf = aProfile;
 
-  gcompris_configuration_window( g_strdup_printf("<b>%s</b> configuration\n for profile <b>%s</b>",
-						 agcomprisBoard->name, 
-						 aProfile->name), 
+  if (gcomprisBoard)
+    pause_board(TRUE);
+
+  gchar * label = g_strdup_printf("<b>%s</b> configuration\n for profile <b>%s</b>",
+				  agcomprisBoard->name, 
+				  aProfile? aProfile->name : "");
+
+  gcompris_configuration_window( label,
 				 (GcomprisConfCallback )conf_ok);
 
+  g_free(label);
+
   /* init the combo to previously saved value */
   GHashTable *config = gcompris_get_conf( profile_conf, board_conf);
 
