@@ -1,6 +1,6 @@
 /* gcompris - smallnumbers.c
  *
- * Time-stamp: <2005/10/12 22:45:09 bruno>
+ * Time-stamp: <2006/03/27 00:54:18 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  * 
@@ -18,6 +18,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
+#include <string.h>
 
 #include "gcompris/gcompris.h"
 
@@ -140,7 +141,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 {
   GHashTable *config = gcompris_get_board_conf();
 
-  locale_sound = g_hash_table_lookup( config, "locale_sound");
+  locale_sound = g_strdup(g_hash_table_lookup( config, "locale_sound"));
 
   gchar *control_sound = g_hash_table_lookup( config, "with_sound");
 
@@ -149,6 +150,8 @@ static void start_board (GcomprisBoard *agcomprisBoard)
   else
     with_sound = FALSE;
 
+  g_hash_table_destroy(config);
+
   if(agcomprisBoard!=NULL)
     {
       gcomprisBoard=agcomprisBoard;
@@ -156,7 +159,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       /* disable im_context */
       gcomprisBoard->disable_im_context = TRUE;
 
-      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/scenery3_background.png");
+      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/scenery7_background.png");
 
       gcomprisBoard->level = 1;
       gcomprisBoard->maxlevel = 9;
@@ -165,7 +168,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 			   gcomprisBoard->width - 220, 
 			   gcomprisBoard->height - 50, 
 			   gcomprisBoard->number_of_sublevel);
-      gcompris_bar_set(GCOMPRIS_BAR_LEVEL);
+      gcompris_bar_set(GCOMPRIS_BAR_CONFIG|GCOMPRIS_BAR_LEVEL);
 
 
       number_of_dices=1;
@@ -208,8 +211,6 @@ set_level (guint level)
 
 static gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str)
 {
-  gchar *old_value;
-  gchar *old_name;
   char str[2];
 
   if(!gcomprisBoard || !boardRootItem)
@@ -298,7 +299,6 @@ static void smallnumbers_next_level()
 /* Destroy all the items */
 static void smallnumbers_destroy_all_items()
 {
-  GnomeCanvasItem *item;
 
   if(boardRootItem!=NULL)
     gtk_object_destroy (GTK_OBJECT(boardRootItem));
@@ -357,14 +357,14 @@ static void smallnumbers_create_item(GnomeCanvasGroup *parent)
   GdkPixbuf *smallnumbers_pixmap = NULL;
   GnomeCanvasItem *item;
   GnomeCanvasGroup *group_item;
-  char *str;
   guint i;
   char *lettersItem;
-  char *str1 = NULL;
-  char *str2 = NULL;
+  gchar *str1 = NULL;
+  gchar *str2 = NULL;
   guint total_number = 0;
   double x = 0.0;
   guint number_of_dice = number_of_dices;
+  gchar *letter;
 
   group_item = GNOME_CANVAS_GROUP(
 				  gnome_canvas_item_new (parent,
@@ -390,7 +390,17 @@ static void smallnumbers_create_item(GnomeCanvasGroup *parent)
 
     lettersItem[1] = '\0';
 
-    str1 = g_strdup_printf("%s%s", lettersItem, ".ogg");
+    gunichar *unichar_letterItem;
+
+    unichar_letterItem = g_new(gunichar,1);
+
+    *unichar_letterItem = g_utf8_get_char (lettersItem);
+
+    letter = g_new0(gchar, 6);
+    g_unichar_to_utf8 ( *unichar_letterItem, letter);
+
+    str1 = gcompris_alphabet_sound(letter);
+
     str2 = gcompris_get_asset_file_locale("gcompris alphabet", NULL, "audio/x-ogg", str1, locale_sound);
 
     if (with_sound)
@@ -399,11 +409,13 @@ static void smallnumbers_create_item(GnomeCanvasGroup *parent)
     g_free(str1);
     g_free(str2);
 
-    str = g_strdup_printf("gcompris/dice/gnome-dice%c.png", numbers[i]);
+    str1 = g_strdup_printf("level%c.png", numbers[i]);
+    str2 = gcompris_image_to_skin(str1);
 
-    smallnumbers_pixmap = gcompris_load_pixmap(str);
+    smallnumbers_pixmap = gcompris_load_pixmap(str2);
 
-    g_free(str);
+    g_free(str1);
+    g_free(str2);
 
     if(x==0.0) {
       x = (double)(rand()%(gcomprisBoard->width-
@@ -489,12 +501,50 @@ static GHFunc save_table (gpointer key,
 			    board_conf,
 			    (gchar *) key, 
 			    (gchar *) value);
+
+  return NULL;
 }
 
 static GcomprisConfCallback conf_ok(GHashTable *table)
 {
+  if (!table){
+    if (gcomprisBoard)
+      pause_board(FALSE);
+    return;
+  }
+
   g_hash_table_foreach(table, (GHFunc) save_table, NULL);
-  
+
+  if (gcomprisBoard){
+    GHashTable *config;
+
+    if (profile_conf)
+      config = gcompris_get_board_conf();
+    else
+      config = table;
+    
+    if (locale_sound)
+      g_free(locale_sound);
+
+    locale_sound = g_strdup(g_hash_table_lookup( config, "locale_sound"));
+    
+    gchar *control_sound = g_hash_table_lookup( config, "with_sound");
+    
+    if (control_sound && strcmp(g_hash_table_lookup( config, "with_sound"),"True")==0)
+      with_sound = TRUE;
+    else
+      with_sound = FALSE;
+    
+    if (profile_conf)
+      g_hash_table_destroy(config);
+
+    smallnumbers_next_level();
+
+    gamewon = FALSE;
+
+    pause_board(FALSE);
+  }
+
   board_conf = NULL;
   profile_conf = NULL;
 }
@@ -519,10 +569,13 @@ smallnumber_config_start(GcomprisBoard *agcomprisBoard,
   board_conf = agcomprisBoard;
   profile_conf = aProfile;
 
+  if (gcomprisBoard)
+    pause_board(TRUE);
+
   gchar *label;
   
   label = g_strdup_printf("<b>%s</b> configuration\n for profile <b>%s</b>",
-			  agcomprisBoard->name, aProfile->name);
+			  agcomprisBoard->name, aProfile ? aProfile->name : "");
 
   gcompris_configuration_window(label, (GcomprisConfCallback )conf_ok);
 
@@ -531,7 +584,7 @@ smallnumber_config_start(GcomprisBoard *agcomprisBoard,
   /* init the combo to previously saved value */
   GHashTable *config = gcompris_get_conf( profile_conf, board_conf);
 
-  locale_sound = g_hash_table_lookup( config, "locale_sound");
+  gchar *saved_locale_sound = g_hash_table_lookup( config, "locale_sound");
 
   gchar *control_sound = g_hash_table_lookup( config, "with_sound");
   if (control_sound && strcmp(g_hash_table_lookup( config, "with_sound"),"True")==0)
@@ -541,7 +594,7 @@ smallnumber_config_start(GcomprisBoard *agcomprisBoard,
 
   GtkCheckButton  *sound_control = gcompris_boolean_box("Enable sounds", "with_sound", with_sound);
   
-  GtkComboBox *sound_box = gcompris_combo_locales_asset( "Select sound locale", locale_sound, "gcompris colors", NULL, "audio/x-ogg", "purple.ogg");
+  GtkComboBox *sound_box = gcompris_combo_locales_asset( "Select sound locale", saved_locale_sound, "gcompris colors", NULL, "audio/x-ogg", "purple.ogg");
 
   gtk_widget_set_sensitive(GTK_WIDGET(sound_box), with_sound);
 
@@ -549,6 +602,8 @@ smallnumber_config_start(GcomprisBoard *agcomprisBoard,
 		   G_CALLBACK(sound_control_box_toggled),
 		   sound_box);
 
+  g_hash_table_destroy(config);
+
 }  
 /* ======================= */
 /* = config_stop        = */
