@@ -1,6 +1,6 @@
 /* gcompris - about.c
  *
- * Time-stamp: <2005/04/10 16:48:33 bruno>
+ * Time-stamp: <2005/10/05 00:57:09 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -100,16 +100,34 @@ void gcompris_about_start ()
   y = BOARDHEIGHT - (BOARDHEIGHT - gdk_pixbuf_get_height(pixmap))/2;
   gdk_pixbuf_unref(pixmap);
 
-  item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
-				gnome_canvas_text_get_type (),
-				"text", _("About GCompris"), 
-				"font", gcompris_skin_font_title,
-				"x", (double) BOARDWIDTH/2,
-				"y", (double) y_start + 40,
-				"anchor", GTK_ANCHOR_CENTER,
-				"fill_color_rgba", gcompris_skin_color_title,
-				NULL);
+  gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
+			 gnome_canvas_text_get_type (),
+			 "text", _("About GCompris"), 
+			 "font", gcompris_skin_font_title,
+			 "x", (double) BOARDWIDTH/2 + 1.0,
+			 "y", (double) y_start + 40 + 1.0,
+			 "anchor", GTK_ANCHOR_CENTER,
+			 "fill_color_rgba", gcompris_skin_color_shadow,
+			 NULL);
+  gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
+			 gnome_canvas_text_get_type (),
+			 "text", _("About GCompris"), 
+			 "font", gcompris_skin_font_title,
+			 "x", (double) BOARDWIDTH/2,
+			 "y", (double) y_start + 40,
+			 "anchor", GTK_ANCHOR_CENTER,
+			 "fill_color_rgba", gcompris_skin_color_title,
+			 NULL);
 
+  gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
+			 gnome_canvas_text_get_type (),
+			 "text", _("Translators:"), 
+			 "font", gcompris_skin_font_subtitle,
+			 "x", (double) BOARDWIDTH/2-320 + 1.0,
+			 "y", (double) y_start + 90 + 1.0,
+			 "anchor", GTK_ANCHOR_NORTH_WEST,
+			 "fill_color_rgba", gcompris_skin_color_shadow,
+			 NULL);
   gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 			 gnome_canvas_text_get_type (),
 			 "text", _("Translators:"), 
@@ -120,6 +138,15 @@ void gcompris_about_start ()
 			 "fill_color_rgba", gcompris_skin_color_subtitle,
 			 NULL);
 
+  gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
+			 gnome_canvas_text_get_type (),
+			 "text", translators,
+			 "font", gcompris_skin_font_content,
+			 "x", (double)  BOARDWIDTH/2-320 + 1.0,
+			 "y", (double)  y_start + 120 + 1.0,
+			 "anchor", GTK_ANCHOR_NORTH_WEST,
+			 "fill_color_rgba", gcompris_skin_color_shadow,
+			 NULL);
   gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 			 gnome_canvas_text_get_type (),
 			 "text", translators,
@@ -132,26 +159,44 @@ void gcompris_about_start ()
   // Version
   y_start += 100;
 
-  item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
-				gnome_canvas_text_get_type (),
-				"text", "GCompris V" VERSION,
-				"font", gcompris_skin_font_title,
-				"x", (double)  BOARDWIDTH/2,
-				"y", (double)  y_start,
-				"anchor", GTK_ANCHOR_CENTER,
-				"fill_color_rgba", gcompris_skin_color_subtitle,
-				NULL);
+  gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
+			 gnome_canvas_text_get_type (),
+			 "text", "GCompris V" VERSION,
+			 "font", gcompris_skin_font_title,
+			 "x", (double)  BOARDWIDTH/2 + 1.0,
+			 "y", (double)  y_start + 1.0,
+			 "anchor", GTK_ANCHOR_CENTER,
+			 "fill_color_rgba", gcompris_skin_color_shadow,
+			 NULL);
+  gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
+			 gnome_canvas_text_get_type (),
+			 "text", "GCompris V" VERSION,
+			 "font", gcompris_skin_font_title,
+			 "x", (double)  BOARDWIDTH/2,
+			 "y", (double)  y_start,
+			 "anchor", GTK_ANCHOR_CENTER,
+			 "fill_color_rgba", gcompris_skin_color_subtitle,
+			 NULL);
 
   y_start += 180;
-  item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
-				gnome_canvas_text_get_type (),
-				"text", gettext(content),
-				"font", gcompris_skin_font_content,
-				"x", (double)  BOARDWIDTH*0.45,
-				"y", (double)  y_start,
-				"anchor", GTK_ANCHOR_CENTER,
-				"fill_color_rgba", gcompris_skin_color_content,
-				NULL);
+  gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
+			 gnome_canvas_text_get_type (),
+			 "text", gettext(content),
+			 "font", gcompris_skin_font_content,
+			 "x", (double)  BOARDWIDTH*0.45 + 1.0,
+			 "y", (double)  y_start + 1.0,
+			 "anchor", GTK_ANCHOR_CENTER,
+			 "fill_color_rgba", gcompris_skin_color_shadow,
+			 NULL);
+  gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
+			 gnome_canvas_text_get_type (),
+			 "text", gettext(content),
+			 "font", gcompris_skin_font_content,
+			 "x", (double)  BOARDWIDTH*0.45,
+			 "y", (double)  y_start,
+			 "anchor", GTK_ANCHOR_CENTER,
+			 "fill_color_rgba", gcompris_skin_color_content,
+			 NULL);
 
   // Ofset Reference
   pixmap = gcompris_load_skin_pixmap("ofsetlogo.png");
@@ -162,17 +207,11 @@ void gcompris_about_start ()
 				"y", (double) y_start - gdk_pixbuf_get_height(pixmap)/2,
 				NULL);
 
-  gtk_signal_connect(GTK_OBJECT(item), "event",
-		     (GtkSignalFunc) item_event_ok,
-		     "ofset");
-  gtk_signal_connect(GTK_OBJECT(item), "event",
-		     (GtkSignalFunc) gcompris_item_event_focus,
-		     NULL);
   gdk_pixbuf_unref(pixmap);
   
   item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				gnome_canvas_text_get_type (),
-				"text", "OFSET",
+				"text", "OFSET\nhttp://ofset.org",
 				"font", gcompris_skin_font_content,
 				"x", (double)  (BOARDWIDTH*0.15),
 				"y", (double)  y_start + 80,
@@ -188,18 +227,11 @@ void gcompris_about_start ()
 				"x", (double) (BOARDWIDTH*0.8) - gdk_pixbuf_get_width(pixmap)/2,
 				"y", (double) y_start - gdk_pixbuf_get_height(pixmap)/2,
 				NULL);
-
-  gtk_signal_connect(GTK_OBJECT(item), "event",
-		     (GtkSignalFunc) item_event_ok,
-		     "fsf");
-  gtk_signal_connect(GTK_OBJECT(item), "event",
-		     (GtkSignalFunc) gcompris_item_event_focus,
-		     NULL);
   gdk_pixbuf_unref(pixmap);
   
   item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				gnome_canvas_text_get_type (),
-				"text", "Free Software Foundation",
+				"text", "Free Software Foundation\nhttp://www.fsf.org",
 				"font", gcompris_skin_font_content,
 				"x", (double)  (BOARDWIDTH*0.75),
 				"y", (double)  y_start + 80,
@@ -217,17 +249,11 @@ void gcompris_about_start ()
 				"y", (double) y_start - gdk_pixbuf_get_height(pixmap)/2,
 				NULL);
 
-  gtk_signal_connect(GTK_OBJECT(item), "event",
-		     (GtkSignalFunc) item_event_ok,
-		     "gcompris");
-  gtk_signal_connect(GTK_OBJECT(item), "event",
-		     (GtkSignalFunc) gcompris_item_event_focus,
-		     NULL);
   gdk_pixbuf_unref(pixmap);
 
   item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				gnome_canvas_text_get_type (),
-				"text", _("GCompris Home Page"),
+				"text", _("GCompris Home Page\nhttp://gcompris.net"),
 				"font", gcompris_skin_font_content,
 				"x", (double)  (BOARDWIDTH*0.5),
 				"y", (double)  y_start + 30,
@@ -238,7 +264,7 @@ void gcompris_about_start ()
   // Copyright
   item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				gnome_canvas_text_get_type (),
-				"text", "Copyright 2000-2003 Bruno Coudoin",
+				"text", "Copyright 2000-2005 Bruno Coudoin",
 				"font", gcompris_skin_font_content,
 				"x", (double)  BOARDWIDTH/2,
 				"y", (double)  y - 95,
@@ -257,48 +283,47 @@ void gcompris_about_start ()
 				"fill_color_rgba", gcompris_skin_color_content,
 				NULL);
 
-  // GCompris HELP
-#ifndef WIN32
-  pixmap = gcompris_load_skin_pixmap("button_large.png");
-  item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
-				gnome_canvas_pixbuf_get_type (),
-				"pixbuf", pixmap, 
-				"x", (double) BOARDWIDTH*0.3 - gdk_pixbuf_get_width(pixmap)/2,
-				"y", (double) y - gdk_pixbuf_get_height(pixmap) - 5,
-				NULL);
+  /* Location for a potential sponsor */
+  gchar *sponsor_image = gcompris_find_absolute_filename("sponsor.png");
+  if(sponsor_image)
+    {
+      gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
+			     gnome_canvas_text_get_type (),
+			     "text", "Version parrainée par",
+			     "font", gcompris_skin_font_content,
+			     "x", (double)  BOARDWIDTH*0.85,
+			     "y", (double)  10,
+			     "anchor", GTK_ANCHOR_CENTER,
+			     "fill_color_rgba", gcompris_skin_color_content,
+			     NULL);
+      gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
+			     gnome_canvas_text_get_type (),
+			     "text", "Version parrainée par",
+			     "font", gcompris_skin_font_content,
+			     "x", (double)  BOARDWIDTH*0.85 + 1,
+			     "y", (double)  10,
+			     "anchor", GTK_ANCHOR_CENTER,
+			     "fill_color", "black",
+			     NULL);
 
-  gtk_signal_connect(GTK_OBJECT(item), "event",
-		     (GtkSignalFunc) item_event_ok,
-		     "help");
-  gtk_signal_connect(GTK_OBJECT(item), "event",
-		     (GtkSignalFunc) gcompris_item_event_focus,
-		     NULL);
-  gdk_pixbuf_unref(pixmap);
+      pixmap = gcompris_load_pixmap("sponsor.png");
+      item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
+				    gnome_canvas_pixbuf_get_type (),
+				    "pixbuf", pixmap, 
+				    "x", (double) (BOARDWIDTH*0.85) - gdk_pixbuf_get_width(pixmap)/2,
+				    "y", (double) 15,
+				    NULL);
 
-
-  item2 = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
-				gnome_canvas_text_get_type (),
-				"text", _("Help"),
-				"font", gcompris_skin_font_title,
-				"x", (double)  BOARDWIDTH*0.3,
-				"y", (double)  y - gdk_pixbuf_get_height(pixmap) + 20,
-				"anchor", GTK_ANCHOR_CENTER,
-				"fill_color_rgba", gcompris_skin_color_text_button,
-				NULL);
-  gtk_signal_connect(GTK_OBJECT(item2), "event",
-		     (GtkSignalFunc) item_event_ok,
-		     "help");
-  gtk_signal_connect(GTK_OBJECT(item2), "event",
-		     (GtkSignalFunc) gcompris_item_event_focus,
-		     item);
-#endif
+      gdk_pixbuf_unref(pixmap);
+      g_free(sponsor_image);
+    }
 
   // OK
   pixmap = gcompris_load_skin_pixmap("button_large.png");
   item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				gnome_canvas_pixbuf_get_type (),
 				"pixbuf", pixmap, 
-				"x", (double) BOARDWIDTH*0.7 - gdk_pixbuf_get_width(pixmap)/2,
+				"x", (double) BOARDWIDTH*0.5 - gdk_pixbuf_get_width(pixmap)/2,
 				"y", (double) y - gdk_pixbuf_get_height(pixmap) - 5,
 				NULL);
 
@@ -311,11 +336,20 @@ void gcompris_about_start ()
   gdk_pixbuf_unref(pixmap);
 
 
+  gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
+			 gnome_canvas_text_get_type (),
+			 "text", _("OK"),
+			 "font", gcompris_skin_font_title,
+			 "x", (double)  BOARDWIDTH*0.5 + 1.0,
+			 "y", (double)  y - gdk_pixbuf_get_height(pixmap) + 20 + 1.0,
+			 "anchor", GTK_ANCHOR_CENTER,
+			 "fill_color_rgba", gcompris_skin_color_shadow,
+			 NULL);
   item2 = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				gnome_canvas_text_get_type (),
 				"text", _("OK"),
 				"font", gcompris_skin_font_title,
-				"x", (double)  BOARDWIDTH*0.7,
+				"x", (double)  BOARDWIDTH*0.5,
 				"y", (double)  y - gdk_pixbuf_get_height(pixmap) + 20,
 				"anchor", GTK_ANCHOR_CENTER,
 				"fill_color_rgba", gcompris_skin_color_text_button,
@@ -428,31 +462,6 @@ item_event_ok(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 	{
 	  gcompris_about_stop();
 	}
-      else if (!strcmp((char *)data, "ofset"))
-	{
-	  /* FIXME: Should inform the user that we don't find mozilla. */
-	  system("mozilla http://www.ofset.org &");
-	}
-      else if (!strcmp((char *)data, "fsf"))
-	{
-	  /* FIXME: Should inform the user that we don't find mozilla. */
-	  system("mozilla http://www.fsf.org &");
-	}
-      else if (!strcmp((char *)data, "gcompris"))
-	{
-	  /* FIXME: Should inform the user that we don't find mozilla. */
-	  system("mozilla http://gcompris.net &");
-	}
-      else if (!strcmp((char *)data, "help"))
-	{
-	  /* It implements gcompris's own way to load help in order to be
-	   * Package relocatable.
-	   * Unfortunatly, this does not supports I18N
-	   */
-	  /* FIXME: Should inform the user that we don't find mozilla. */
-	  system("mozilla "PACKAGE_HELP_DIR"/C/gcompris.html &");
-
-	}
     default:
       break;
     }
