@@ -1,6 +1,6 @@
 /* gcompris - bar.c
  *
- * Time-stamp: <2005/10/03 21:36:37 bruno>
+ * Time-stamp: <2006/03/12 03:02:12 bruno>
  *
  * Copyright (C) 2000-2003 Bruno Coudoin
  *
@@ -54,6 +54,8 @@ static guint level_handler_id;
 
 static gint sound_play_id = 0;
 
+static void  confirm_quit(gboolean answer);
+
 /*
  * Main entry point 
  * ----------------
@@ -66,7 +68,7 @@ static gint sound_play_id = 0;
  */
 void gcompris_bar_start (GnomeCanvas *theCanvas)
 {
-
+  GcomprisProperties *properties = gcompris_get_properties();
   GdkPixbuf   *pixmap = NULL;
   GnomeCanvasItem *rootitem;
   gint16           width, height;
@@ -94,25 +96,27 @@ void gcompris_bar_start (GnomeCanvas *theCanvas)
   gdk_pixbuf_unref(pixmap);
 
   // EXIT
-  pixmap = gcompris_load_skin_pixmap("button_exit.png");
-  zoom = (double)(height-BAR_GAP)/(double)gdk_pixbuf_get_height(pixmap);
-  exit_item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
-				     gnome_canvas_pixbuf_get_type (),
-				     "pixbuf", pixmap, 
-				     "x", (double) (width/NUMBER_OF_ITEMS) * 1 -
-				     gdk_pixbuf_get_width(pixmap)/2,
-				     "y", (double) (height-gdk_pixbuf_get_height(pixmap)*zoom)/2,
-				     NULL);
-  gdk_pixbuf_unref(pixmap);
+  if(properties->disable_quit == 0)
+    {
+      pixmap = gcompris_load_skin_pixmap("button_exit.png");
+      zoom = (double)(height-BAR_GAP)/(double)gdk_pixbuf_get_height(pixmap);
+      exit_item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
+					 gnome_canvas_pixbuf_get_type (),
+					 "pixbuf", pixmap, 
+					 "x", (double) (width/NUMBER_OF_ITEMS) * 1 -
+					 gdk_pixbuf_get_width(pixmap)/2,
+					 "y", (double) (height-gdk_pixbuf_get_height(pixmap)*zoom)/2,
+					 NULL);
+      gdk_pixbuf_unref(pixmap);
 
-  gtk_signal_connect(GTK_OBJECT(exit_item), "event",
-		     (GtkSignalFunc) item_event_bar,
-		     "quit");
-
-  gtk_signal_connect(GTK_OBJECT(exit_item), "event",
-		     (GtkSignalFunc) gcompris_item_event_focus,
-		     NULL);
+      gtk_signal_connect(GTK_OBJECT(exit_item), "event",
+			 (GtkSignalFunc) item_event_bar,
+			 "quit");
 
+      gtk_signal_connect(GTK_OBJECT(exit_item), "event",
+			 (GtkSignalFunc) gcompris_item_event_focus,
+			 NULL);
+    }
   
   // HOME
   pixmap = gcompris_load_skin_pixmap("home.png");
@@ -218,24 +222,27 @@ void gcompris_bar_start (GnomeCanvas *theCanvas)
 		     NULL);
 
   // CONFIG
-  pixmap = gcompris_load_skin_pixmap("config.png");
-  zoom = (double)(height-BAR_GAP)/(double)gdk_pixbuf_get_height(pixmap);
-  config_item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
-				     gnome_canvas_pixbuf_get_type (),
-				     "pixbuf", pixmap, 
-				     "x", (double) (width/NUMBER_OF_ITEMS) * 3 -
-				     gdk_pixbuf_get_width(pixmap)/2,
-				     "y", (double) (height-gdk_pixbuf_get_height(pixmap)*zoom)/2,
-				     NULL);
-  gdk_pixbuf_unref(pixmap);
+  if(properties->disable_config == 0)
+    {
+      pixmap = gcompris_load_skin_pixmap("config.png");
+      zoom = (double)(height-BAR_GAP)/(double)gdk_pixbuf_get_height(pixmap);
+      config_item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
+					   gnome_canvas_pixbuf_get_type (),
+					   "pixbuf", pixmap, 
+					   "x", (double) (width/NUMBER_OF_ITEMS) * 3 -
+					   gdk_pixbuf_get_width(pixmap)/2,
+					   "y", (double) (height-gdk_pixbuf_get_height(pixmap)*zoom)/2,
+					   NULL);
+      gdk_pixbuf_unref(pixmap);
 
-  gtk_signal_connect(GTK_OBJECT(config_item), "event",
-		     (GtkSignalFunc) item_event_bar,
-		     "configuration");
+      gtk_signal_connect(GTK_OBJECT(config_item), "event",
+			 (GtkSignalFunc) item_event_bar,
+			 "configuration");
 
-  gtk_signal_connect(GTK_OBJECT(config_item), "event",
-		     (GtkSignalFunc) gcompris_item_event_focus,
-		     NULL);
+      gtk_signal_connect(GTK_OBJECT(config_item), "event",
+			 (GtkSignalFunc) gcompris_item_event_focus,
+			 NULL);
+    }
 
   // ABOUT
   pixmap = gcompris_load_skin_pixmap("about.png");
@@ -263,7 +270,8 @@ void gcompris_bar_start (GnomeCanvas *theCanvas)
   gnome_canvas_item_show(ok_item);
   gnome_canvas_item_show(help_item);
   gnome_canvas_item_show(repeat_item);
-  gnome_canvas_item_show(config_item);
+  if(config_item)
+    gnome_canvas_item_show(config_item);
   gnome_canvas_item_show(about_item);
 }
 
@@ -362,7 +370,7 @@ gcompris_bar_set (const GComprisBarFlags flags)
       gnome_canvas_item_hide(repeat_item);
   }
 
-  if(flags&GCOMPRIS_BAR_CONFIG)
+  if(flags&GCOMPRIS_BAR_CONFIG && config_item)
     gnome_canvas_item_show(config_item);
   else
     gnome_canvas_item_hide(config_item);
@@ -385,13 +393,15 @@ gcompris_bar_hide (gboolean hide)
 {
   if(hide)
     {
-      gnome_canvas_item_hide(exit_item);
+      if(exit_item)
+	gnome_canvas_item_hide(exit_item);
       gnome_canvas_item_hide(home_item);
       gnome_canvas_item_hide(level_item);
       gnome_canvas_item_hide(ok_item);
       gnome_canvas_item_hide(help_item);
       gnome_canvas_item_hide(repeat_item);
-      gnome_canvas_item_hide(config_item);
+      if(config_item)
+	gnome_canvas_item_hide(config_item);
       gnome_canvas_item_hide(about_item);
     }
   else
@@ -418,12 +428,14 @@ static void update_exit_button()
   if (get_current_gcompris_board()->previous_board == NULL)
     {
       /* We are in the upper menu: show it */
-      gnome_canvas_item_show(exit_item);
+      if(exit_item)
+	gnome_canvas_item_show(exit_item);
       gnome_canvas_item_hide(home_item);
     }
   else
     {
-      gnome_canvas_item_hide(exit_item);
+      if(exit_item)
+	gnome_canvas_item_hide(exit_item);
       gnome_canvas_item_show(home_item);
     }
 }
@@ -506,7 +518,9 @@ item_event_bar(GnomeCanvasItem *item, GdkEvent *event, gchar *data)
 
 	  if(tmp!=current_level)
 	    {
-	      current_level_str = g_strdup_printf("%d.ogg", current_level);
+	      char *number_str = g_strdup_printf("%d", current_level);
+	      current_level_str = gcompris_alphabet_sound(number_str);
+	      g_free(number_str);
 
 	      str_level  = gcompris_get_asset_file("gcompris misc",     NULL, "audio/x-ogg", "level.ogg");
 	      str_number = gcompris_get_asset_file("gcompris alphabet", NULL, "audio/x-ogg", current_level_str);
@@ -542,9 +556,10 @@ item_event_bar(GnomeCanvasItem *item, GdkEvent *event, gchar *data)
 	}
       else if(!strcmp((char *)data, "configuration"))
 	{
-	  if(gcomprisBoard->plugin->config != NULL)
+	  if(gcomprisBoard->plugin->config_start != NULL)
 	    {
-	      gcomprisBoard->plugin->config();
+	      gcomprisBoard->plugin->config_start(gcomprisBoard,
+						  gcompris_get_current_profile());
 	    }
 	}
       else if(!strcmp((char *)data, "about"))
@@ -553,7 +568,11 @@ item_event_bar(GnomeCanvasItem *item, GdkEvent *event, gchar *data)
 	}
       else if(!strcmp((char *)data, "quit"))
 	{
-	  gcompris_exit();
+	  gcompris_confirm( _("GCompris confirmation"),
+			    _("Sure you want to quit ?"),
+			    _("Yes, I am sure !"),
+			    _("No, I want to keep going"),
+			    (ConfirmCallBack) confirm_quit);
 	}
       break;
       
@@ -564,7 +583,12 @@ item_event_bar(GnomeCanvasItem *item, GdkEvent *event, gchar *data)
 
 }
 
-
+static void
+confirm_quit(gboolean answer)
+{
+  if (answer)
+    gcompris_exit();
+}
 
 
 /* Local Variables: */
