@@ -100,7 +100,6 @@ void end_board_finished() {
 #define OFFSET 100
 void board_finished(BoardFinishedList type) {
   GcomprisBoard *gcomprisBoard = get_current_gcompris_board();
-  GcomprisProperties	*properties = gcompris_get_properties();
 
   int x,y;
   GdkPixbuf *pixmap_door1 = NULL,*pixmap_door2 = NULL,*pixmap_tuxplane = NULL;
@@ -199,7 +198,6 @@ void board_finished(BoardFinishedList type) {
 void gcompris_display_bonus(BonusStatusList gamewon, BonusList bonus_id)
 {
   GcomprisBoard *gcomprisBoard = get_current_gcompris_board();
-  GcomprisProperties	*properties = gcompris_get_properties();
 
   gcompris_bar_hide(TRUE);
 
@@ -309,6 +307,15 @@ void bonus_image(char *image, BonusStatusList gamewon)
 
 
   if(gamewon==BOARD_DRAW) {
+    gnome_canvas_item_new (bonus_group,
+			   gnome_canvas_text_get_type (),
+			   "text", _("Drawn game"),
+			   "font", gcompris_skin_font_title,
+			   "x", (double) BOARDWIDTH/2 + 1.0,
+			   "y", (double) gdk_pixbuf_get_height(pixmap) + 1.0,
+			   "anchor", GTK_ANCHOR_CENTER,
+			   "fill_color", "black",
+			   NULL);
     gnome_canvas_item_new (bonus_group,
 			   gnome_canvas_text_get_type (),
 			   "text", _("Drawn game"),
