@@ -116,6 +116,9 @@ static char *popt_profile	   = NULL;
 static int *popt_profile_list	   = FALSE;
 static char *popt_shared_dir	   = NULL;
 static char *popt_users_dir	   = NULL;
+static int  popt_experimental      = FALSE;
+static int  popt_no_quit	   = FALSE;
+static int  popt_no_config         = FALSE;
 
 static struct poptOption options[] = {
   {"fullscreen", 'f', POPT_ARG_NONE, &popt_fullscreen, 0,
@@ -160,6 +163,12 @@ static struct poptOption options[] = {
    N_("Shared directory location, for profiles and board-configuration data: [$HOME/.gcompris/shared]"), NULL},
   {"users-dir",'\0', POPT_ARG_STRING, &popt_users_dir, 0,
    N_("The location of user directories: [$HOME/.gcompris/users]"), NULL},
+  {"experimental",'\0', POPT_ARG_NONE, &popt_experimental, 0,
+   N_("Run the experimental activities"), NULL},
+  {"disable-quit",'\0', POPT_ARG_NONE, &popt_no_quit, 0,
+   N_("Disable the quit button"), NULL},
+  {"disable-config",'\0', POPT_ARG_NONE, &popt_no_config, 0,
+   N_("Disable the config button"), NULL},
 #ifndef WIN32	/* Not supported on windows */
   POPT_AUTOHELP
 #endif
@@ -772,8 +781,8 @@ static void setup_window ()
   board_play (board_to_start);
 
 #ifdef WIN32
-#define WIN_ACTIVITY_COUNT   15
-#define TOTAL_ACTIVITY_COUNT 55
+#define WIN_ACTIVITY_COUNT   16
+#define TOTAL_ACTIVITY_COUNT 58
   {
     if(strncmp(properties->key, "thanks_for_your_help", 20)!=0) {
       char *msg = g_strdup_printf(_("GCompris is free software released under the GPL License. In order to support its development, the Windows version provides only %d of the %d activities. You can get the full version for a small fee at\n<http://gcompris.net>\nThe Linux version does not have this restriction. Note that GCompris is being developed to free schools from monopolistic software vendors. If you also believe that we should teach freedom to children, please consider using GNU/Linux. Get more information at FSF:\n<http://www.fsf.org/philosophy>"), WIN_ACTIVITY_COUNT, TOTAL_ACTIVITY_COUNT);
@@ -905,18 +914,18 @@ static void map_cb (GtkWidget *widget, gpointer data)
       is_mapped = TRUE;
       gcompris_set_fullscreen(properties->fullscreen);
     }
-
-  printf("\nEVENT\n============================================================\n\n");
+  g_warning("gcompris window is now mapped");
 }
 
 /* 
  * Process the cleanup of the child (no zombies)
  * ---------------------------------------------
  */
-void gcompris_terminate(int  signum)
+void gcompris_terminate(int signum)
 {
 
-  g_warning("gcompris got the %s signal, starting exit procedure", strsignal(signum));
+  g_warning("gcompris got the %d signal, starting exit procedure", signum);
+
   gcompris_exit();
   
 }
@@ -1212,6 +1221,24 @@ gcompris_init (int argc, char *argv[])
       antialiased = TRUE;
     }
 
+  if (popt_experimental)
+    {
+      g_warning("Experimental boards allowed");
+      properties->experimental  = TRUE;
+    }
+
+  if (popt_no_quit)
+    {
+      g_warning("Disable quit button");
+      properties->disable_quit = TRUE;
+    }
+
+  if (popt_no_config)
+    {
+      g_warning("Disable config button");
+      properties->disable_config = TRUE;
+    }
+
   if (popt_difficulty_filter>=0)
     {
       /* This option provide less capacity than the GUI since we cannot set the filter_style */
@@ -1229,7 +1256,7 @@ gcompris_init (int argc, char *argv[])
     if (strcmp(popt_root_menu,"list")==0){
       /* check the list of possible values for -l, then exit */
       printf(_("Use -l to access an activity directly.\n"));
-      printf(_("List of available activity is :\n"));
+      printf(_("The list of available activities is :\n"));
       properties->root_menu = "/";
 
       gcompris_db_init();
@@ -1264,6 +1291,7 @@ gcompris_init (int argc, char *argv[])
     else {
     g_warning("Using menu %s as root.", popt_root_menu);
     properties->root_menu = g_strdup(popt_root_menu);
+    properties->menu_position = g_strdup(popt_root_menu);
     }
   }
 
