@@ -1,6 +1,6 @@
 /* gcompris - gcompris.h
  *
- * Time-stamp: <2005/11/11 12:50:47 bruno>
+ * Time-stamp: <2006/03/02 00:02:09 bruno>
  *
  * Copyright (C) 2000,2001,2002 Bruno Coudoin
  *
@@ -53,6 +53,7 @@
 #include "gcompris_files.h"
 #include "wordlist.h"
 #include "gcompris_im.h"
+#include "gcompris_alphabeta.h"
 
 #ifdef USE_CAIRO
 #include "gcompris-cairo.h"
@@ -96,6 +97,7 @@ typedef enum
   GCOMPRIS_BAR_CONFIG	   = 1 << 3,
   GCOMPRIS_BAR_ABOUT	   = 1 << 4,
   GCOMPRIS_BAR_REPEAT_ICON = 1 << 5,
+  GCOMPRIS_BAR_QUIT	   = 1 << 6,
 } GComprisBarFlags;
 
 /* Difficulty filtering */
@@ -147,6 +149,16 @@ void		 gcompris_exit();
 
 gchar		*gcompris_get_database();
 
+typedef void     (*ConfirmCallBack)     (gboolean answer);
+
+void gcompris_confirm (gchar *title, 
+		       gchar *question_text,
+		       gchar *yes_text,
+		       gchar *no_text,
+		       ConfirmCallBack iscb);
+
+void gcompris_confirm_stop (void);
+
 /* Trace Log */
 #define GCOMPRIS_LOG_STATUS_PASSED    "PASSED"
 #define GCOMPRIS_LOG_STATUS_FAILED    "FAILED"
