@@ -20,6 +20,8 @@
 #include <string.h>
 
 #include "gcompris.h"
+#include <sys/stat.h>
+
 
 #ifdef USE_SQLITE
 static sqlite3 *gcompris_db=NULL;
@@ -128,7 +130,21 @@ int gcompris_db_init()
   
   if (!g_file_test(properties->database, G_FILE_TEST_EXISTS))
     creation = TRUE;
+  else {
+    /* we have to check this file is not empty,
+       because bug in administration */
+    struct stat buf;
+    
+    if (stat(properties->database, &buf)!=0)
+      g_error("Can't stat %s", properties->database);
 
+    /* if size of file is null, we recreate the tables */
+    if (buf.st_size == 0){
+      creation = TRUE;
+      g_warning("Database file is empty! Trying to create table...");
+    }
+  }
+    
   rc = sqlite3_open(properties->database, &gcompris_db);
   if( rc ){
     g_error("Can't open database: %s\n", sqlite3_errmsg(gcompris_db));
@@ -235,7 +251,7 @@ int gcompris_db_init()
 
     request = g_strdup_printf("INSERT INTO class (class_id, name, teacher, wholegroup_id) VALUES ( 1, \'%s\', \'(%s)\', 1);",
 			      _("Unaffected"),
-			      _("Users without class"));
+			      _("Users without a class"));
 
     rc = sqlite3_exec(gcompris_db, request, NULL,  0, &zErrMsg);
     if( rc!=SQLITE_OK ){
@@ -414,8 +430,8 @@ gboolean gcompris_db_check_boards()
         "SELECT board_id FROM boards WHERE name=\'%s\';",n
 
 
-void gcompris_db_board_update(gint *board_id,
-			      gint *section_id,
+void gcompris_db_board_update(guint *board_id,
+			      guint *section_id,
 			      gchar *name,
 			      gchar *section,
 			      gchar *author,
