@@ -1,6 +1,6 @@
 /* gcompris - properties.c
  *
- * Time-stamp: <2005/11/05 23:15:45 bruno>
+ * Time-stamp: <2006/03/02 01:08:31 bruno>
  *
  * Copyright (C) 2000,2003 Bruno Coudoin
  *
@@ -168,6 +168,8 @@ GcomprisProperties *gcompris_properties_new ()
   tmp->difficulty_max    = 0;
   tmp->filter_style      = GCOMPRIS_FILTER_NONE;	/* No difficulty filter by default */
   tmp->difficulty_filter = 1;				/* No difficulty filter by default */
+  tmp->disable_quit      = 0;				/* Used to remove the quit button from the bar. Use it for kiosk mode */
+  tmp->disable_config    = 0;				/* Used to remove the config button from the bar. Use it for kiosk mode */
   tmp->root_menu         = "/";
   tmp->local_directory   = NULL;
   tmp->package_data_dir  = PACKAGE_DATA_DIR;
@@ -176,6 +178,8 @@ GcomprisProperties *gcompris_properties_new ()
 
   tmp->administration    = FALSE;
   tmp->reread_menu       = FALSE;
+  tmp->experimental      = FALSE;
+  tmp->menu_position     = NULL;
 
   gcompris_user_dir = get_gcompris_user_root_directory() ;
   create_rootdir( gcompris_user_dir );
@@ -249,6 +253,12 @@ GcomprisProperties *gcompris_properties_new ()
 	} else if(!strcmp(value.v_identifier, "difficulty_filter")) {
 	  if(!scan_get_int(scanner, &tmp->difficulty_filter))
 	    g_warning("Config file parsing error on token %s", token);
+	} else if(!strcmp(value.v_identifier, "disable_quit")) {
+	  if(!scan_get_int(scanner, &tmp->disable_quit))
+	    g_warning("Config file parsing error on token %s", token);
+	} else if(!strcmp(value.v_identifier, "disable_config")) {
+	  if(!scan_get_int(scanner, &tmp->disable_config))
+	    g_warning("Config file parsing error on token %s", token);
 	} else if(!strcmp(value.v_identifier, "filter_style")) {
 	  if(!scan_get_int(scanner, &tmp->filter_style))
 	    g_warning("Config file parsing error on token %s", token);
@@ -341,16 +351,8 @@ void gcompris_properties_save (GcomprisProperties *props)
   fprintf(filefd, "%s=%d\n", "fx",			props->fx);
   fprintf(filefd, "%s=%d\n", "screensize",		props->screensize);
   fprintf(filefd, "%s=%d\n", "fullscreen",		props->fullscreen);
-  /* FIXME: No more persist the noxrandr option until we provide a way to set it back
-   *
-   fprintf(filefd, "%s=%d\n", "noxrandr",		props->noxrandr); */
   fprintf(filefd, "%s=%d\n", "timer",			props->timer);
 
-  /* No more need to persist these, it's in the base now
-     fprintf(filefd, "%s=%d\n", "difficulty_filter",	props->difficulty_filter);
-     fprintf(filefd, "%s=%d\n", "filter_style",		props->filter_style);
-  */
-
   fprintf(filefd, "%s=\"%s\"\n", "skin",		props->skin);
   fprintf(filefd, "%s=\"%s\"\n", "locale",		props->locale);
   fprintf(filefd, "%s=\"%s\"\n", "key",			props->key);
